<?php
namespace Faturamento\Logic\Cda;

use \Geral\Util\NovoCodigo;
use \Geral\Util\Ambiente;
use \Geral\Util\Util;

use \Setforms2\Runtime\Helper\Procedure;
use \Setforms2\Runtime\Helper\Procedure\Param;

/**
 * Regras de negócio relacionadas às rotinas de gravação/atualização de CDA (Controle Diário de Atividades).
 *
 * @author newtonsantos
 */
class ProcessoCda {
    
    /**
     * Consulta próxima número sequencial de Serviço Prestado.
     *
     * @param integer $nrOrg           Numero da organizacao.
     *
     * @return $servprest['NRSERVPREST']
     *
     * @author newtonsantos
     */
    public static function getProxNrServPrest($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest) {
        $servprestRepository = \Faturamento\Entities\Servprest::getRepository();
        $servprest = $servprestRepository->consultaProxNrServPrest($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest);

        return $servprest[0]['NRSERVPREST'];
    }
    
    private static function setEditAuditValues($entity) {
        $nrorgatual = \Geral\Util\Ambiente::getNrorg(); 
        $dtatual = \Geral\Util\DateUtil::getDataAtual();
        $cdoperatual = \Geral\Util\Ambiente::getCdOperador();
        
        $entity->setDtultatu($dtatual);
        $entity->setNrorgultatu($nrorgatual);
        $entity->setCdoperultatu($cdoperatual);
        
        $dtinclusao = $entity->getDtinclusao();
        if($dtinclusao == null) {
            $entity->setDtinclusao($dtatual);
            $entity->setNrorginclusao($nrorgatual);
            $entity->setCdoperinclusao($cdoperatual);
        }
    }
    
    /**
     * retorna um sequencial para CONTATO.
     *
     * @return string
     *
     * @author newtonsantos - 19/07/2013
     */
    private static function geraNovoCodigoContato($cdfilial) {
        return Novocodigo::geraCodigo(Ambiente::getNrorg(), 'CONTATO'.$cdfilial);
    }

    public static function gravaContatoCDA($nrorg, $cdempresa, $cdfunc, $idservprest, $dtservprest, $cdfilial, $nrcontato, $cdcliente, $cdinteclie, $cdprospect, $cdintepros, $nmintevocont, $cdmoticont, $cdsistema, $dthrevolcont, $cdmotievocon, $dsevolcont, $cdoperador) {
        $contatogravado = array();
        
        $operador = \Geral\Entities\Operador::getRepository()->findOneBy(array(
            "cdempresa" => $cdempresa, 
            "cdfunc" => $cdfunc,
            "nrorg" => $nrorg
        )); 
        $cdopercont = is_object($operador) ? $operador->GetCdoperador() : '';
        
        $dtatual = \Geral\Util\DateUtil::getDataAtual();
        $dthrservprest = \Geral\Util\DateUtil::getDataDeString($dtservprest, \Geral\Util\DateUtil::FORMATO_BRASILEIRO, true);
                
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        try {
            
            /* Gravação da tabela CONTATO
             */
            if(is_null($nrcontato) || $nrcontato == '') {
                $contato = new \Geral\Entities\Contato();

                $nrcontato = self::geraNovoCodigoContato($cdfilial);
                $idstatuscont = 'A';
                $dthrcontato = $dthrservprest;
                $idtpcontato = ($idservprest == 'RELACIONAMENTO_CLIENTE') ? 'C' : 'P';
                $dsrefecont = ($idservprest == 'RELACIONAMENTO_CLIENTE') ? tk_get_message_by_name('msg_win_int00001_000_RelacCliente') : tk_get_message_by_name('msg_win_int00001_000_VisitaProspect');
                
            } else {
                $contato = \Geral\Entities\Contato::getRepository()->findOneBy(array(
                    "cdfilial" => $cdfilial,
                    "nrcontato" => $nrcontato,
                    "nrorg" => $nrorg
                ));

                if(is_object($contato)) {
                    $idstatuscont = $contato->getIdstatuscont();
                    $dthrcontato = $contato->getDthrcontato();
                    $idtpcontato = $contato->getIdtpcontato();
                    $dsrefecont = $contato->getDsrefecont();
                    $cdopercont = $contato->getCdopercont();
                }
            }
            if(is_object($contato)) {
                $contato->setNrorg($nrorg);
                $contato->setCdfilial($cdfilial);
                $contato->setNrcontato($nrcontato);
                $contato->setCdmoticont($cdmoticont);
                $contato->setCdsistema($cdsistema);
                if($idservprest == 'RELACIONAMENTO_CLIENTE') {
                    $contato->setCdcliente($cdcliente);
                } else {
                    $contato->setCdprospect($cdprospect);
                }
                $contato->setDthrcontato($dthrcontato);
                $contato->setDsrefecont($dsrefecont);
                $contato->setIdstatuscont($idstatuscont);
                $contato->setIdtpcontato($idtpcontato);
                $contato->setCdopercont($cdopercont);
                $contato->setNrorg($nrorg);
                self::setEditAuditValues($contato);
                $contato->persist();
            
                $connection->flush();
            }
            
            /* Gravação da tabela EVOLCONT
             */

            if($idservprest == 'RELACIONAMENTO_CLIENTE') {
                $inteclie = \Geral\Entities\Inteclie::getRepository()->findOneBy(array(
                    "cdcliente" => $cdcliente, 
                    "cdinteclie" => $cdinteclie,
                    "nrorg" => $nrorg
                )); 
                
                $nrrelacionaparc = $inteclie->getNrrelacionaparc();
            } else {
                $inteprosp = \Geral\Entities\Inteprosp::getRepository()->findOneBy(array(
                    "cdprospect" => $cdprospect, 
                    "cdintepros" => $cdintepros,
                    "nrorg" => $nrorg
                )); 
                
                $nrrelacionaparc = $inteprosp->getNrrelacionaparc();
            }
            
            if(is_null($dthrevolcont) || $dthrevolcont == '') {
                $evolCont = new \Relatione\Entities\Evolcont();
                
                $dthrevolcont = $dtatual;
                $cdtipocont = '60';  // '60' - Visita
                $idsenevocont = 'S'; // 'S' - Saída
                $idtpevolcont = ($idservprest == 'RELACIONAMENTO_CLIENTE') ? 'C' : 'P';
                $cdfasecont = '036'; // '036' - Visita comercial
                $idageevocont = 'N';
                $dthrinclevocont = $dthrservprest;
                $idanexoevolcont = 'N';

                $evolcontRepository = \Relatione\Entities\Evolcont::getRepository();
                $evolcontRep = $evolcontRepository->consultaProxSequencialEvolCont($nrorg, $cdfilial, $nrcontato);

                $nrseqevolcon = $evolcontRep[0]['NRSEQEVOLCON'];
            } else {
                $dthrevolcont = \Geral\Util\DateUtil::getDataDeString($dthrevolcont, \Geral\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA);
                        
                $evolCont = \Relatione\Entities\Evolcont::getRepository()->findOneBy(array(
                    "cdfilial" => $cdfilial, 
                    "nrcontato" => $nrcontato, 
                    "dthrevolcont" => $dthrevolcont, 
                    "nrorg" => $nrorg
                ));

                if(is_object($evolCont)) {
                    $dthrevolcont = $evolCont->getDthrevolcont();
                    $cdtipocont = $evolCont->getCdtipocont();
                    $idsenevocont = $evolCont->getIdsenevocont();
                    $idtpevolcont = $evolCont->getIdtpevolcont();
                    $cdfasecont = $evolCont->getCdfasecont();
                    $idageevocont = $evolCont->getIdageevocont();
                    $dthrinclevocont = $evolCont->getDthrinclevocont();
                    $idanexoevolcont = $evolCont->getIdanexoevolcont();
                    $nrseqevolcon = $evolCont->getNrseqevolcon();
                }
            }

            if(strlen($nrseqevolcon) > 2) {
                $nrseqevolcon = 99;
            }

            if(is_object($evolCont)) {
                $evolCont->setNrorg($nrorg);
                $evolCont->setCdfilial($cdfilial);
                $evolCont->setNrcontato($nrcontato);
                $evolCont->setDthrevolcont($dthrevolcont);
                $evolCont->setCdtipocont($cdtipocont); 
                if($idservprest == 'RELACIONAMENTO_CLIENTE') {
                    $evolCont->setCdcliente($cdcliente);
                    $evolCont->setCdinteclie($cdinteclie);
                } else {
                    $evolCont->setCdprospect($cdprospect);
                    $evolCont->setCdintepros($cdintepros);
                }
                if(is_null($evolCont->getNrseqevolcont())) {
                    $evolCont->setNrseqevolcont(\Geral\Util\NovoCodigo::geraCodigo($nrorg, 'EVOLCONT', 1));
                }
                $evolCont->setNrrelacionaparc($nrrelacionaparc);
                $evolCont->setNmintevocont($nmintevocont);
                $evolCont->setIdsenevocont($idsenevocont);
                $evolCont->setIdtpevolcont($idtpevolcont);
                $evolCont->setDsevolcont($dsevolcont);
                $evolCont->setCdfasecont($cdfasecont); 
                $evolCont->setIdageevocont($idageevocont);
                //$evolCont->setCdoperevol($cdopercont);
                $evolCont->setCdoperevol($cdoperador);
                $evolCont->setNrseqevolcon($nrseqevolcon);
                $evolCont->setCdmotievocon($cdmotievocon);
                $evolCont->setDthrinclevocont($dthrinclevocont);
                $evolCont->setIdanexoevolcont($idanexoevolcont);
                self::setEditAuditValues($evolCont);
                $evolCont->persist();
            
                $connection->flush();
            }
            
            $contatogravado['NRCONTATO'] = $nrcontato;
            $contatogravado['DTHREVOLCONT'] = $dthrevolcont->format(\Geral\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA);
            
        } catch (\Exception $e) {
            throw $e;
        }
        
        return $contatogravado;
    }
    
    public static function atualizaTelEmailInterlocutor($nrorg, $idservprest, $cdcliente, $cdinteclie, $cdprospect, $cdintepros, $nrtelintclpr, $dsemailintclpr) {
        $atualizainterlocutor = false;
                
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        try {
            if($idservprest == 'VISITA_PROSPECT') {
                $inteProsp = \Geral\Entities\Inteprosp::getRepository()->findOneBy(array(
                    "cdprospect" => $cdprospect, 
                    "cdintepros" => $cdintepros,
                    "nrorg" => $nrorg
                ));
                if (is_object($inteProsp)) {
                    $inteProsp->setNrtel1inpros($nrtelintclpr);
                    $inteProsp->setDsemailipros($dsemailintclpr);
                    self::setEditAuditValues($inteProsp);
                    $inteProsp->persist();
                }
            }
            
            if($idservprest == 'RELACIONAMENTO_CLIENTE') {
                $inteClie = \Geral\Entities\Inteclie::getRepository()->findOneBy(array(
                    "cdcliente" => $cdcliente, 
                    "cdinteclie" => $cdinteclie,
                    "nrorg" => $nrorg
                ));
                if (is_object($inteClie)) {
                    $inteClie->setNrtel1inclie($nrtelintclpr);
                    $inteClie->setDsemailiclie($dsemailintclpr);
                    self::setEditAuditValues($inteClie);
                    $inteClie->persist();
                }
            }
            
            $connection->flush();
            
            $atualizainterlocutor = true;
        } catch (\Exception $e) {
            throw $e;
        }
        
        return $atualizainterlocutor;
    }

    public static function gravaDescricaoCDA($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest, $dsservprest, $is_new_dsservprest) {
        $dtservprest = \Geral\Util\DateUtil::getDataDeString($dtservprest, \Geral\Util\DateUtil::FORMATO_BRASILEIRO, true);
        
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        try {
            if($is_new_dsservprest) {
                $descServPres = new \Faturamento\Entities\Descservpres();
            } else {
                $descServPres = \Faturamento\Entities\Descservpres::getRepository()->findOneBy(array(
                    "cdempresa" => $cdempresa, 
                    "cdfunc" => $cdfunc, 
                    "cdcliente" => $cdcliente, 
                    "dtservprest" => $dtservprest, 
                    "nrservprest" => $nrservprest,
                    "nrorg" => $nrorg
                ));
            }
            
            if (is_object($descServPres)) {
                $descServPres->setCdempresa($cdempresa);
                $descServPres->setCdfunc($cdfunc);
                $descServPres->setCdcliente($cdcliente);
                $descServPres->setDtservprest($dtservprest);
                $descServPres->setNrservprest($nrservprest);
                $descServPres->setNrorg($nrorg);
                $descServPres->setDsservprest($dsservprest);
                self::setEditAuditValues($descServPres);
                $descServPres->persist();
            }
            
            $connection->flush();
        } catch (\Exception $e) {
            throw $e;
        }
            
        return is_object($descServPres) ? $descServPres : false;
    }
    
    public static function deleteCda($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest, $idservprest) {
        $deletecda = false;
        $dtstservprest = $dtservprest;
        $dtservprest = \Geral\Util\DateUtil::getDataDeString($dtservprest, \Geral\Util\DateUtil::FORMATO_BRASILEIRO, true);
        
        $db = \Setforms2\Runtime\Connection::getInstance();
        $db->getConn()->beginTransaction();
        try {
            self::verificaDelete($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest);
            self::deletaBatidaPonto($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest);
            self::deletaAproativCsa($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest);
            self::deletaDescservpres($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest);
            $dados = self::deletaServprest($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest);
            
            if($idservprest == 'VISITA_PROSPECT' || $idservprest == 'RELACIONAMENTO_CLIENTE') {
                self::deletaEvolCont($dados['CDFILIAL'], $dados['NRCONTATO'], $dados['DTHREVOLCONT'], $nrorg);
            }

            if($idservprest == 'FALTA_NAO_JUSTIFICADA') {
                self::totalizaFaltasCDA($nrorg, $cdempresa, $cdfunc, $dtstservprest);
            }
            $db->getConn()->commit();
            $deletecda = true;
        } catch (\Exception $e) {
            $db->getConn()->rollback();
            tk_message(tk_get_message_by_name($e->getMessage()), 'warning');
        }
        
        return $deletecda;
    }
    
    private static function verificaDelete($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest){

        $id = array(
            "cdempresa"   => $cdempresa, 
            "cdfunc"      => $cdfunc, 
            "cdcliente"   => $cdcliente, 
            "dtservprest" => $dtservprest, 
            "nrservprest" => $nrservprest,
            "nrorg"       => $nrorg
        );

        $aproAtivCsas = \Indeterminado\Entities\Aproativcsa::getRepository()->findBy($id);
        foreach ($aproAtivCsas as $aproAtivCsa) {
            if($aproAtivCsa->getVrpercconcl() >= 100){
                throw new \Exception('msg_cda_nao_pode_ser_excluida');
            }               
        }
    }
    
    private static function deletaEvolCont($cdfilial, $nrcontato, $dthrevolcont, $nrorg){
        
        $connection = \Setforms2\Shared\Registry::getEntityManager();  

        $evolCont = \Relatione\Entities\Evolcont::getRepository()->findOneBy(array(
                "cdfilial" => $cdfilial, 
                "nrcontato" => $nrcontato, 
                "dthrevolcont" => $dthrevolcont, 
                "nrorg" => $nrorg
            ));
            if (is_object($evolCont)) {
                $evolCont->delete();
            }

        $connection->flush();            
      
    }
    
    private static function deletaBatidaPonto($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest){
        
        $connection = \Setforms2\Shared\Registry::getEntityManager();  

        $batidasPonto = \Folha\Entities\Batidaponto::getRepository()->findBy(array(
            "cdempresa" => $cdempresa, 
            "cdfunc" => $cdfunc, 
            "cdcliente" => $cdcliente, 
            "dtservprest" => $dtservprest, 
            "nrservprest" => $nrservprest,
            "nrorg" => $nrorg
        ));
        foreach ($batidasPonto as $batidaPonto) {
            $batidaPonto->delete();

        }

        $connection->flush();                 
    }
    
    private static function deletaAproativCsa($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest){

        $connection = \Setforms2\Shared\Registry::getEntityManager(); 
        $id = array(
            "cdempresa" => $cdempresa, 
            "cdfunc" => $cdfunc, 
            "cdcliente" => $cdcliente, 
            "dtservprest" => $dtservprest, 
            "nrservprest" => $nrservprest,
            "nrorg" => $nrorg
        );

        $aproAtivCsas = \Indeterminado\Entities\Aproativcsa::getRepository()->findBy($id);
        foreach ($aproAtivCsas as $aproAtivCsa) {
            $aproAtivCsa->delete();                
        }
        $connection->flush();  
    }
    
    private static function deletaDescservpres($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest){
        
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        $descServPres = \Faturamento\Entities\Descservpres::getRepository()->findOneBy(array(
            "cdempresa" => $cdempresa, 
            "cdfunc" => $cdfunc, 
            "cdcliente" => $cdcliente, 
            "dtservprest" => $dtservprest, 
            "nrservprest" => $nrservprest,
            "nrorg" => $nrorg
        ));
        if (is_object($descServPres)) {
            $descServPres->delete();
            $connection->flush();
        }
    }
    
    private static function deletaServprest($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest){
        
        $connection = \Setforms2\Shared\Registry::getEntityManager(); 
        $id = array(
            "cdempresa" => $cdempresa, 
            "cdfunc" => $cdfunc, 
            "cdcliente" => $cdcliente, 
            "dtservprest" => $dtservprest, 
            "nrservprest" => $nrservprest,
            "nrorg" => $nrorg
        );
        $servPrest = \Faturamento\Entities\Servprest::getRepository()->findOneBy($id);
        if (is_object($servPrest)) {
            $dados['CDFILIAL']     = $servPrest->getCdfilial();
            $dados['NRCONTATO']    = $servPrest->getNrcontato();
            $dados['DTHREVOLCONT'] = $servPrest->getDthrevolcont();

            $servPrest->delete();
            $connection->flush(); 
        }
     
        return $dados;
    }
    
    
    public static function confirmaCda($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest) {
        $dtservprest = \Geral\Util\DateUtil::getDataDeString($dtservprest, \Geral\Util\DateUtil::FORMATO_BRASILEIRO, true);
        $idsitservprest = 'C';
        
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        try {
            $servPrest = \Faturamento\Entities\Servprest::getRepository()->findOneBy(array(
                "cdempresa" => $cdempresa, 
                "cdfunc" => $cdfunc, 
                "cdcliente" => $cdcliente, 
                "dtservprest" => $dtservprest, 
                "nrservprest" => $nrservprest,
                "nrorg" => $nrorg
            ));
            
            if (is_object($servPrest)) {
                $dtentrada = $servPrest->getDtentrada();
                $dtsaida = $servPrest->getDtsaida();
                
                if(is_null($dtentrada) || $dtentrada == '' || is_null($dtsaida) || $dtsaida == '') {
                    $confirmacda = false;
                } else {
                    $servPrest->setIdsitservprest($idsitservprest);
                    self::setEditAuditValues($servPrest);
                    $servPrest->persist();
                    $connection->flush();
                    
                    $confirmacda = $servPrest;
                }
            }
            
        } catch (\Exception $e) {
            throw $e;
        }
            
        return $confirmacda;
    }
    
    public static function corrigeCda($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest) {
        $dtservprest = \Geral\Util\DateUtil::getDataDeString($dtservprest, \Geral\Util\DateUtil::FORMATO_BRASILEIRO, true);
        $idsitservprest = 'P';
        
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        try {
            $servPrest = \Faturamento\Entities\Servprest::getRepository()->findOneBy(array(
                "cdempresa" => $cdempresa, 
                "cdfunc" => $cdfunc, 
                "cdcliente" => $cdcliente, 
                "dtservprest" => $dtservprest, 
                "nrservprest" => $nrservprest, 
                "nrorg" => $nrorg
            ));
            
            if (is_object($servPrest)) {
                $servPrest->setIdsitservprest($idsitservprest);
                self::setEditAuditValues($servPrest);
                $servPrest->persist();
            }
            
            $connection->flush();
        } catch (\Exception $e) {
            throw $e;
        }
            
        return is_object($servPrest) ? $servPrest : false;
    }
    
    /**
     * Rotina para totalização das faltas não justificadas apontadas através da CDA.
     *
     * @param integer $nrOrg           Numero da organizacao.
     *
     * @author newtonsantos
     */
    public static function totalizaFaltasCDA($nrorg, $cdempresa, $cdfunc, $dtservprest) {
        try {
            $procedure = new Procedure("FPA_CDA_TOTALIZA");
            $procedure->addParam(new Param(
                "P_NRORG",
                Param::PARAM_INPUT,
                $nrorg,
                Param::PARAM_TYPE_INT
            ));
            $procedure->addParam(new Param(
                "P_CDEMPRESA",
                Param::PARAM_INPUT,
                $cdempresa,
                Param::PARAM_TYPE_STR
            ));
            $procedure->addParam(new Param(
                "P_CDFUNC",
                Param::PARAM_INPUT,
                $cdfunc,
                Param::PARAM_TYPE_STR
            ));
            $procedure->addParam(new Param(
                "P_DTPONTO",
                Param::PARAM_INPUT,
                $dtservprest,
                Param::PARAM_TYPE_STR
            ));
            $procedure->call();
        } catch (\Exception $e) {
            throw $e;
        }
    }
    
    public static function updateAprovaAtividade($nrorg, $cdfilial, $cdprojeto, $cdvercronprj, $cdseqcronprj, $nrbaselinepr, $dtservprest, $vrpercconcl){
        $aprovaatividade = array();
        
        $dtatual = \Geral\Util\DateUtil::getDataAtual();
            
        $connection = \Setforms2\Shared\Registry::getEntityManager();
        $connection->beginTransaction();
            
        try {
            $cronoprojeto = \Teknisa\Entities\Cronoprojeto::getRepository()->findOneBy(array(
                "cdfilial"     => $cdfilial,
                "cdprojeto"    => $cdprojeto,
                "cdvercronprj" => $cdvercronprj,
                "cdseqcronprj" => $cdseqcronprj,
                "nrbaselinepr" => $nrbaselinepr
            ));
            if(is_object($cronoprojeto)) {
                $nrtarefa = $cronoprojeto->getNrtarefa();
                $nrplativtare = $cronoprojeto->getNrplativtare();

                $cronoprojeto->setVrperconcprj($vrpercconcl);
                $cronoprojeto->persist();
            }
            
            if(!is_object($dtservprest)){
                if(strlen($dtservprest) > 10){
                    $dtservprest = \Geral\Util\DateUtil::getDataDeString($dtservprest, \Geral\Util\DateUtil::FORMATO_BRASILEIRO_DATAHORA,true);
                }
                else{
                    $dtservprest = \Geral\Util\DateUtil::getDataDeString($dtservprest, \Geral\Util\DateUtil::FORMATO_BRASILEIRO,true);
                }
            }

            $planativtare = \Geral\Entities\Planativtare::getRepository()->findOneBy(array(
                "nrorg"        => $nrorg,
                "nrtarefa"     => $nrtarefa,
                "nrplativtare" => $nrplativtare,
                "cdfilial"     => $cdfilial                    
            ));
            if(is_object($planativtare)) {
                if($vrpercconcl >= '100') {
                    $aprovaatividade['DTFIRATIVTAR'] = $dtservprest->format(\Geral\Util\DateUtil::FORMATO_BRASILEIRO);
                    $aprovaatividade['IDSITATIVTAR'] = "C";
                    
                    $planativtare->setDtfirativtar($dtservprest);
                    $planativtare->setIdsitativtar("C");
                    $planativtare->setDtconativtar($dtservprest);
                }
                else{
                    $aprovaatividade['DTFIRATIVTAR'] = null;
                    $aprovaatividade['IDSITATIVTAR'] = "P";
                    
                    $planativtare->setDtfirativtar(null);
                    $planativtare->setIdsitativtar("P");
                    $planativtare->setDtconativtar(null);
                }
                $planativtare->setDthraprovativta($dtatual);
                $planativtare->persist();
            }

            $connection->flush();
            $connection->commit();
        } catch (\Exception $e) {
            $connection->rollback();
            throw $e;
        }
        
        return $aprovaatividade;
    }
    
    public static function getNrservcontAndNrseqageserv($nrproposfas, $nrverpropfas, $cdtiposerv, $nrorg, $dtservprest, $cdempresa, $cdfunc){
        $agendaServRepository = \Faturamento\Entities\Agendaserv::getRepository();
        $dadosAgendaServ      = $agendaServRepository->consultaNrservcontAndNrseqageserv($nrproposfas, $nrverpropfas, $cdtiposerv, $nrorg, $dtservprest, $cdempresa, $cdfunc);
        $dadosEncontrados     = array('NRSERVCONT'   => $dadosAgendaServ[0]['NRSERVCONT'],
                                      'NRSEQAGESERV' => $dadosAgendaServ[0]['NRSEQAGESERV']
                                     );
        return $dadosEncontrados;     
    }
    
    public static function returnBoolExistsCDA($nrorg, $cdempresa, $cdfunc, $cdcliente, $dtservprest, $nrservprest)
    {
        $where = "NRORG           = ?
                  AND CDEMPRESA   = ?
                  AND CDFUNC      = ?
                  AND CDCLIENTE   = ?
                  AND NRSERVPREST = ?
                  AND TO_CHAR(DTSERVPREST, 'DD/MM/YYYY') = ?";
        
        $params = array($nrorg, $cdempresa, $cdfunc, $cdcliente, $nrservprest, $dtservprest);
        
        $servPrest = \Faturamento\Entities\Servprest::getObjectsByWhere($where, $params);
        
        if(!empty($servPrest)) {
            return true;
        }
        
        return false;
    }
}